#[repr(C)]pub struct OH_NativeBuffer_Plane {
pub offset: u64,
pub rowStride: u32,
pub columnStride: u32,
}Available on crate feature
api-12 only.Expand description
Holds info for a single image plane.
Required System Capabilities: SystemCapability.Graphic.Graphic2D.NativeBuffer
Available since API-level: 12
Version: 1.0
Fields
offset: u64< Offset in bytes of plane.
rowStride: u32< Distance in bytes from the first value of one row of the image to the first value of the next row.
columnStride: u32< Distance in bytes from the first value of one column of the image to the first value of the next column.