get native window buffer colorGamut,
variable parameter in function is
[out] int32_t *colorGamut, the enumeration value refers to [OH_NativeBuffer_ColorGamut].
get the timeout in milliseconds when the native window requests a buffer,
the default value is 3000 milliseconds when not set,
variable parameter in function is
[out] int32_t *timeout, in milliseconds.
get native window buffer transform,
variable parameter in function is
[out] int32_t *transform, the enumeration value refers to [OH_NativeBuffer_TransformType].
set native window buffer colorGamut,
variable parameter in function is
[in] int32_t colorGamut, the enumeration value refers to [OH_NativeBuffer_ColorGamut].
set the timeout in milliseconds when the native window requests a buffer,
the default value is 3000 milliseconds when not set,
variable parameter in function is
[in] int32_t timeout, in milliseconds.
set native window buffer transform,
variable parameter in function is
[in] int32_t transform, the enumeration value refers to [OH_NativeBuffer_TransformType].